@@ -169,6 +169,9 @@ class Config:
         supports, and the code here doesn't need to get fancy with function arguments
 
         """
+        # drop any loaded config
+        self.loaded = {}
+        # add the plugin to our list.
         return self.plugins.add_plugin(Type.SOURCE, plugin_id, instance_id, priority)
 
     def load(self, label: str, force_reload: bool = False, validator: str = ""):
@@ -226,6 +229,7 @@ class Config:
         if validator:
             self.validate(self.loaded[label].data, validator)
 
+        logger.debug("Loaded config {} : {}".format(label, self.loaded[label].data))
         return self.loaded[label]
 
     """ Formatter plugin usage and management """
